<template>
    <div class="app-data-chart <#if ctrl.getPSSysCss()??><#assign singleCss = ctrl.getPSSysCss()> ${singleCss.getCssName()}</#if>">
<#if ctrl.render??><#t>
        ${ctrl.render.code}
<#else><#t>
        <div class="app-charts" :id="chartId" style="<#if ctrl.getWidth() gt 0>width: ${ctrl.getWidth()};</#if>height: <#if ctrl.getHeight() gt 0>${ctrl.getHeight()}px<#else>100%</#if>;padding: 6px 0;"></div>
</#if>
  </div>
</template>

<#assign import_block>
import echarts from 'echarts';
import { ChartLineSeries } from '@/model/chart-detail';
</#assign>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_HEADER-BASE.vue.ftl
</#ibizinclude>

    /**
     * 获取多项数据
     *
     * @returns {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getDatas(): any[] {
        return [];
    }

    /**
     * 获取单项树
     *
     * @returns {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getData(): any {
        return null;
    }

    /**
     * 显示处理提示
     *
     * @type {boolean}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Prop({ default: true }) protected showBusyIndicator!: boolean;

    /**
     * 部件行为--fetch
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Prop() protected fetchAction!: string;  

    /**
    * Vue声明周期(组件初始化完毕)
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public created() {
         this.afterCreated();     
    }

    /**
    * 执行created后的逻辑
    *
    * @memberof ${srfclassname('${ctrl.codeName}')}
    */
    public afterCreated(){
        if (this.viewState) {
            this.viewStateEvent = this.viewState.subscribe(({ tag, action, data }) => {
                if (!Object.is(tag, this.name)) {
                    return;
                }
                if (Object.is('load', action)) {
                    this.load(data);
                }
            });
        }  
    }

    /**
     * vue 生命周期
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    protected destroyed() {
        this.afterDestroy();
    }

    /**
     * 执行destroyed后的逻辑
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    protected afterDestroy() {
        if (this.viewStateEvent) {
            this.viewStateEvent.unsubscribe();
        }
        <#if destroyed_block??>
        ${destroyed_block}
        </#if>
    }

    /**
     * 图表div绑定的id
     *
     * @type {}
     * @memberof ${srfclassname('${ctrl.name}')}
     */   
    public chartId:string = this.$util.createUUID();

    /**
     * echarts图表对象
     *
     * @type {}
     * @memberof ${srfclassname('${ctrl.name}')}
     */   
    public myChart:any;

    /**
     * 初始化图表所需参数
     *
     * @type {}
     * @memberof ${srfclassname('${ctrl.name}')}
     */   
    public chartOption:any = {
        <#-- 标题start -->
        <#if ctrl.getPSDEChartTitle()??>
        <#assign title= ctrl.getPSDEChartTitle() />
        title:{
            show:<#if title.isShowTitle()>true<#else>false</#if> ,
            text:'<#if title.getTitle()??>${title.getTitle()}</#if>',
            subtext:'<#if title.getSubTitle()??>${title.getSubTitle()}</#if>'
        },
        </#if>
        <#-- 标题end -->
        <#-- 图例start -->
        <#if ctrl.getPSDEChartLegend()??>
        <#assign legend= ctrl.getPSDEChartLegend() />
        legend:{
            show:<#if legend.isShowLegend()>true<#else>false</#if>
        },
        </#if>
        <#-- 图例end -->
        <#-- 绘图网格start -->
        <#if ctrl.getPSChartGrids()??>
        grid:[
            <@ibizindent blank=8>
            <#list ctrl.getPSChartGrids() as chartGrid>
            ${P.getPartCode(chartGrid).code}<#if chartGrid_has_next>,</#if>
            </#list>
            </@ibizindent>
        ],
        </#if>
        <#-- 绘图网格end -->
        <#-- X轴start -->
        <#if ctrl.getPSChartXAxises()??>
        xAxis: [
            <@ibizindent blank=8>
            <#list ctrl.getPSChartXAxises() as chartXAxise>
            ${P.getPartCode(chartXAxise).code}<#if chartXAxise_has_next>,</#if>
            </#list>
            </@ibizindent>
        ],
        </#if>
        <#-- X轴end -->
        <#-- Y轴start -->
        <#if ctrl.getPSChartYAxises()??>
        yAxis:[
            <@ibizindent blank=8>
            <#list ctrl.getPSChartYAxises() as chartYAxise>
            ${P.getPartCode(chartYAxise).code}<#if chartYAxise_has_next>,</#if>
            </#list>
            </@ibizindent>
        ],
        </#if>
        <#-- Y轴end -->
        <#-- 提示框组件start -->
        tooltip:{
            show:true
        },
        <#-- 提示框组件end -->
        <#-- 数据集start -->
        dataset:{
           source:[
            ['Matcha Latte', 50, 30.4, 65.1, 53.3, 83.8, 98.7],
            ['Milk Tea', 100, 92.1, 85.7, 83.1, 73.4, 55.1],
            ['Cheese Cocoa', 50, 67.2, 79.5, 86.4, 65.2, 82.5],
            ['Walnut Brownie', 50, 67.1, 69.2, 72.4, 53.9, 39.1]
           ] 
        },
        <#-- 数据集end -->
        <#-- 序列start -->
        series:[
            <@ibizindent blank=8>
            <#list ctrl.getPSDEChartSerieses() as chartSeriese>
             ${P.getPartCode(chartSeriese).code}<#if chartSeriese_has_next>,</#if>
            </#list>
            </@ibizindent>
        ]
        <#-- 序列end -->
    };

    /**
     * 图表基础配置参数
     * 
     * @returns {*} 
     * @memberof ${srfclassname('${ctrl.name}')}Service
     */
    public defaultConfig: any = {
    
    }

    /**
     * 刷新
     *
     * @param {*} [opt={}]
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    protected refresh(opt: any = {}) {
        this.load(opt);
    }

    /**
     * 获取图表数据
     * 
     * @returns {*} 
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    public load(opt?:any) {
        let _this = this;
        const arg: any = { ...opt };
        const parentdata: any = {};
        this.$emit('beforeload', parentdata);
        Object.assign(arg, parentdata);
        Object.assign(arg,{viewparams:this.viewparams});
        this.service.search(this.fetchAction,JSON.parse(JSON.stringify(this.context)),arg,this.showBusyIndicator).then((res) => {
            if (res) {
                console.log(res);
                _this.drawCharts();
            }
        }).catch((error) => {
            console.error(error);
        });
    }

    /**
     * 绘制图表
     * 
     * @returns {*} 
     * @memberof ${srfclassname('${ctrl.name}')}
     */
    public drawCharts(){
        if(!this.myChart){
          let element:any =  document.getElementById(this.chartId);
          this.myChart = echarts.init(element);
        }
        this.myChart.setOption(this.chartOption);
        this.myChart.resize();
    }


<#ibizinclude>
../@MACRO/CONTROL/CONTROL_BOTTOM-BASE.vue.ftl
</#ibizinclude>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL-BASE.style.ftl
</#ibizinclude>